@@ -1,8 +1,9 @@
-import React, { useMemo } from 'react';
+import { useMemo } from 'react';
 
 import { SceneComponentProps, sceneGraph, SceneObjectBase } from '@grafana/scenes';
 import { shareDashboardType } from 'app/features/dashboard/components/ShareModal/utils';
 import { SceneShareTabState } from 'app/features/dashboard-scene/sharing/types';
+import { getDashboardSceneFor } from 'app/features/dashboard-scene/utils/utils';
 
 import { SharePDFBase } from '../SharePDF';
 import { toReportSceneVariables } from '../utils/variables';
@@ -17,8 +18,8 @@ export class SharePDFTab extends SceneObjectBase<SceneShareTabState> {
 }
 
 function SharePDFTabRenderer({ model }: SceneComponentProps<SharePDFTab>) {
-  const { modalRef, dashboardRef } = model.useState();
-  const dashboard = dashboardRef.resolve();
+  const { modalRef } = model.useState();
+  const dashboard = getDashboardSceneFor(model);
 
   const variables = useMemo(() => {
     const sceneGraphVars = sceneGraph.getVariables(dashboard).state.variables;
